@@ -57,7 +57,7 @@ class Event(object):
             returned["time"] = None
             returned["madechatmod"] = False
         elif connection["event"] == "part":
-            returned["user"] = connect["data"]["attrs"][""]
+            returned["user"] = connection["data"]["attrs"][""]
             returned["text"] = None
             returned["status"] = None
             returned["time"] = None
